On segunda-feira, 22 de janeiro de 2018 01:37:40 PST Thiago Macieira wrote: > CBOR parsing: > 341,311535 task-clock > 885.053.081 cycles > 2.548.803.851 instructions > > The string parser is still showing up at 70.5% of the full execution time, > of which 33.4% are in QCborStreamReader and 20.4% calling isValidUtf8(). > The program spends 25,0% inside QIODevice, inside the string decoder. > Unlike the JSON parser, we don't operate on a pre-read byte array, but > directly on the QIODevice, checking for size.
I've further optimised isValidUtf8() and now the string parser is only 61% of the execution time, with isValidUtf8() down to 7.7%. https://codereview.qt-project.org/217084 for the optimisations. -- Thiago Macieira - thiago.macieira (AT) intel.com Software Architect - Intel Open Source Technology Center _______________________________________________ Development mailing list [email protected] http://lists.qt-project.org/mailman/listinfo/development
